#include <stdio.h>      
#include <stdlib.h>     
#include <unistd.h>
#include <getopt.h>  
#include <qapplication.h>
#include <qmainwindow.h>
#include <qmenubar.h>   
#include <qpopupmenu.h>
#include <qxml.h>
#include "parser.h"
#include "mixer.h"

static struct option options[] =
        {{"help", 0, 0, 'h'},
         {"ctl_name", 1, 0, 'c'}, 
         {"gui_name", 1, 0, 'g'}, 
         {"verbose", 0, 0, 'v'},
         {"printDefaultGui", 0, 0, 'p'},
         {0, 0, 0, 0}};

int main(int argc, char *argv[])  
{
  QApplication *qApp = new QApplication(argc, argv);
  QMainWindow *top = new QMainWindow();
  top->setCaption("QAMix");
  int getopt_return;
  int option_index; 
  int channel = 0;
  QString ctl_name = "hw:0";
  QString xml_name = "NO_NAME_SPECIFIED";
  bool verbose = false;
  bool printDefaultGui = false;

  while((getopt_return = getopt_long(argc, argv, "hvpc:g:", options, &option_index)) >= 0) {
    switch(getopt_return) {
    case 'c':
        ctl_name = QString(optarg);
        break;
    case 'g':
        xml_name = QString(optarg);
        break;
    case 'h':
        printf("\n%s\n", aboutText.latin1());
        printf("-h, --help                      print this help message]\n");
        printf("-v, --verbose                   list all CTL elements\n");
        printf("-p, --printDefaultGui           print default GUI description\n");
        printf("-c <name>, --ctl_name <name>    name of CTL [hw:0]\n");
        printf("-g <name>, --gui_name <name>    GUI desciption file [deflt_mixer.xml]\n");
        exit(EXIT_SUCCESS);
    case 'v':
        verbose = true;
        break;
    case 'p':
        printDefaultGui = true;
        break;
    }
  }
  Mixer *mixer = new Mixer(ctl_name, xml_name, top);
  if (verbose) {
    mixer->listControls();
  }
  if (printDefaultGui) {
    mixer->printDefaultGui();
  }
  QPopupMenu *filePopup = new QPopupMenu(top); 
  QPopupMenu *aboutMenu = new QPopupMenu(top);
  top->menuBar()->insertItem("&File", filePopup);
  top->menuBar()->insertSeparator(); top->menuBar()->insertItem("&About", aboutMenu); 
  filePopup->insertItem("&Quit", qApp, SLOT(quit()));
  aboutMenu->insertItem("About QAMix", mixer->gui, SLOT(displayAbout())); 
  QObject::connect(qApp, SIGNAL(aboutToQuit()), mixer, SLOT(close_mixer()));
  top->setCentralWidget(mixer->gui); 
  top->show();
  qApp->setMainWidget(top); 
  return qApp->exec(); 
}
